@@ -226,9 +226,13 @@ class DummyDriver(driver.ShareDriver):
 
     @slow_me_down
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
-        return self._create_share(share, share_server=share_server)
+        export_locations = self._create_share(share, share_server=share_server)
+        return {
+            'export_locations': export_locations,
+            'status': constants.STATUS_AVAILABLE
+        }
 
     def _create_snapshot(self, snapshot, share_server=None):
         snapshot_name = self._get_snapshot_name(snapshot)
@@ -316,6 +320,11 @@ class DummyDriver(driver.ShareDriver):
                    " could not be found" % old_share_id)
             raise exception.ShareBackendException(msg=msg)
 
+    @slow_me_down
+    def manage_existing_with_server(
+            self, share, driver_options, share_server=None):
+        return self.manage_existing(share, driver_options)
+
     def _get_share_id_from_export(self, export_location):
         values = export_location.split('share_')
         if len(values) > 1:
@@ -329,6 +338,15 @@ class DummyDriver(driver.ShareDriver):
         self.private_storage.update(
             share['id'], {'export_location': share['export_location']})
 
+    @slow_me_down
+    def unmanage_with_server(self, share, share_server=None):
+        self.unmanage(share)
+
+    @slow_me_down
+    def manage_existing_snapshot_with_server(self, snapshot, driver_options,
+                                             share_server=None):
+        return self.manage_existing_snapshot(snapshot, driver_options)
+
     @slow_me_down
     def manage_existing_snapshot(self, snapshot, driver_options):
         """Brings an existing snapshot under Manila management."""
@@ -360,6 +378,10 @@ class DummyDriver(driver.ShareDriver):
             snapshot['id'],
             {'provider_location': snapshot['provider_location']})
 
+    @slow_me_down
+    def unmanage_snapshot_with_server(self, snapshot, share_server=None):
+        self.unmanage_snapshot(snapshot)
+
     @slow_me_down
     def revert_to_snapshot(self, context, snapshot, share_access_rules,
                            snapshot_access_rules, share_server=None):
@@ -395,6 +417,7 @@ class DummyDriver(driver.ShareDriver):
             "service_ip": network_info[
                 "admin_network_allocations"][0]["ip_address"],
             "username": "fake_username",
+            "server_id": network_info['server_id']
         }
         return server_details
 
@@ -672,11 +695,160 @@ class DummyDriver(driver.ShareDriver):
                   })
         return {"total_progress": total_progress}
 
+    def share_server_migration_check_compatibility(
+            self, context, share_server, dest_host, old_share_network,
+            new_share_network, shares_request_spec):
+        """Is called to check migration compatibility for a share server."""
+        backend_name = share_utils.extract_host(
+            dest_host, level='backend_name')
+        config = get_backend_configuration(backend_name)
+        compatible = 'Dummy' in config.share_driver
+        return {
+            'compatible': compatible,
+            'writable': compatible,
+            'preserve_snapshots': compatible,
+            'nondisruptive': False,
+            'share_network_id': new_share_network['id'],
+            'migration_cancel': compatible,
+            'migration_get_progress': compatible
+        }
+
+    @slow_me_down
+    def share_server_migration_start(self, context, src_share_server,
+                                     dest_share_server, shares, snapshots):
+        """Is called to perform 1st phase of migration of a share server."""
+        LOG.debug(
+            "Migration of dummy share server with ID '%s' has been started.",
+            src_share_server["id"])
+        self.migration_progress[src_share_server['id']] = 0
+
+    @slow_me_down
+    def share_server_migration_continue(self, context, src_share_server,
+                                        dest_share_server, shares, snapshots):
+        """Is called to continue the migration of a share server."""
+        if src_share_server["id"] not in self.migration_progress:
+            self.migration_progress[src_share_server["id"]] = 0
+
+        self.migration_progress[src_share_server["id"]] += 50
+
+        LOG.debug(
+            "Migration of dummy share server with ID '%s' is continuing, %s.",
+            src_share_server["id"],
+            self.migration_progress[src_share_server["id"]])
+
+        return self.migration_progress[src_share_server["id"]] >= 100
+
+    @slow_me_down
+    def share_server_migration_complete(self, context, source_share_server,
+                                        dest_share_server, shares, snapshots,
+                                        new_network_allocations):
+        """Is called to complete the migration of a share server."""
+        shares_updates = {}
+        pools = self._get_pools_info()
+        for instance in shares:
+
+            share_name = self._get_share_name(instance)
+            mountpoint = "/path/to/fake/share/%s" % share_name
+            export_locations = self._generate_export_locations(
+                mountpoint, share_server=dest_share_server)
+            dest_pool = pools[0]['pool_name']
+            shares_updates.update(
+                {instance['id']: {'export_locations': export_locations,
+                                  'pool_name': dest_pool}}
+            )
+
+        snapshot_updates = {}
+        for instance in snapshots:
+            snapshot_name = self._get_snapshot_name(instance)
+            mountpoint = "/path/to/fake/snapshot/%s" % snapshot_name
+            snap_export_locations = self._generate_export_locations(
+                mountpoint, share_server=dest_share_server)
+            snapshot_updates.update(
+                {instance['id']: {
+                    'provider_location': mountpoint,
+                    'export_locations': snap_export_locations}}
+            )
+
+        LOG.debug(
+            "Migration of dummy share server with ID '%s' has been completed.",
+            source_share_server["id"])
+        self.migration_progress.pop(source_share_server["id"], None)
+
+        return {
+            'share_updates': shares_updates,
+            'snapshot_updates': snapshot_updates,
+        }
+
+    @slow_me_down
+    def share_server_migration_cancel(self, context, src_share_server,
+                                      dest_share_server, shares, snapshots):
+        """Is called to cancel a share server migration."""
+        LOG.debug(
+            "Migration of dummy share server with ID '%s' has been canceled.",
+            src_share_server["id"])
+        self.migration_progress.pop(src_share_server["id"], None)
+
+    @slow_me_down
+    def share_server_migration_get_progress(self, context, src_share_server,
+                                            dest_share_server, shares,
+                                            snapshots):
+        """Is called to get share server migration progress."""
+        if src_share_server["id"] not in self.migration_progress:
+            self.migration_progress[src_share_server["id"]] = 0
+        total_progress = self.migration_progress[src_share_server["id"]]
+        LOG.debug("Progress of current dummy share server migration "
+                  "with ID '%(id)s' is %(progress)s.", {
+                      "id": src_share_server["id"],
+                      "progress": total_progress
+                  })
+        return {"total_progress": total_progress}
+
     def update_share_usage_size(self, context, shares):
         share_updates = []
         gathered_at = timeutils.utcnow()
         for s in shares:
             share_updates.append({'id': s['id'],
-                                  'used_size':  1,
+                                  'used_size': 1,
                                   'gathered_at': gathered_at})
         return share_updates
+
+    @slow_me_down
+    def get_share_server_network_info(
+            self, context, share_server, identifier, driver_options):
+        try:
+            server_details = self.private_storage.get(identifier)
+        except Exception:
+            msg = ("Unable to find share server %s in "
+                   "private storage." % identifier)
+            raise exception.ShareBackendException(msg=msg)
+
+        return [server_details['primary_public_ip'],
+                server_details['secondary_public_ip'],
+                server_details['service_ip']]
+
+    @slow_me_down
+    def manage_server(self, context, share_server, identifier, driver_options):
+        server_details = self.private_storage.get(identifier)
+        self.private_storage.delete(identifier)
+        return identifier, server_details
+
+    def unmanage_server(self, server_details, security_services=None):
+        server_details = server_details or {}
+        if not server_details or 'server_id' not in server_details:
+            # This share server doesn't have any network details. Since it's
+            # just being cleaned up, we'll log a warning and return without
+            # errors.
+            LOG.warning("Share server does not have network information. "
+                        "It is being unmanaged, but cannot be re-managed "
+                        "without first creating network allocations in this "
+                        "driver's private storage.")
+            return
+        self.private_storage.update(server_details['server_id'],
+                                    server_details)
+
+    def get_share_status(self, share, share_server=None):
+        return {
+            'status': constants.STATUS_AVAILABLE,
+            'export_locations': self.private_storage.get(share['id'],
+                                                         key='export_location')
+        }
